==> novprog-3.0.0-1-src.tar.xz: novprog-3.0.0/translations/novprog_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Bar</name>
    <message numerus="yes">
        <location filename="../src/graph.cpp" line="40"/>
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>מילה %Ln</numerusform>
            <numerusform>%Ln מילים</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation>בחר שפת יישום:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="170"/>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="170"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>אנא אתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>NovelDialog</name>
    <message>
        <location filename="../src/novel_dialog.cpp" line="47"/>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="51"/>
        <source>Goals</source>
        <translation>יעדים</translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="56"/>
        <location filename="../src/novel_dialog.cpp" line="61"/>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="64"/>
        <source>Date Range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="75"/>
        <source>Word Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="89"/>
        <source>Total:</source>
        <translation>סך הכל:</translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="90"/>
        <source>Daily:</source>
        <translation>יומי:</translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="93"/>
        <source>Start On:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="94"/>
        <source>End On:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="97"/>
        <source>Start At:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="111"/>
        <source>Add Novel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="120"/>
        <source>Edit Novel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="137"/>
        <source>Sorry</source>
        <translation>מצטערים</translation>
    </message>
    <message>
        <location filename="../src/novel_dialog.cpp" line="137"/>
        <source>A novel already exists with that name.</source>
        <translation>כבר קיים רומן עם שם זה.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="33"/>
        <source>Novel Progress</source>
        <translation>התקדמות רומן</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="68"/>
        <source>Total</source>
        <translation>סך הכל</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="73"/>
        <source>Daily</source>
        <translation>יומי</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="81"/>
        <source>Word count:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="111"/>
        <source>&amp;Novel</source>
        <translation>&amp;רומן</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="91"/>
        <source>&amp;New Novel</source>
        <translation>רומן &amp;חדש</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="92"/>
        <source>&amp;Edit Novel</source>
        <translation>&amp;ערוך רומן</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="93"/>
        <source>&amp;Delete Novel</source>
        <translation>&amp;מחק רומן</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="95"/>
        <location filename="../src/window.cpp" line="116"/>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="112"/>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>&amp;Edit</source>
        <translation>&amp;ערוך</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="114"/>
        <source>&amp;Delete</source>
        <translation>&amp;מחק</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="182"/>
        <source>Delete novel?</source>
        <translation>למחוק רומן?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="183"/>
        <source>Delete progress for the novel &apos;%1&apos;?</source>
        <translation>למחוק התקדמות עבור הרומן &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="184"/>
        <source>This action cannot be undone.</source>
        <translation>פעולה זו היא בלתי הפיכה.</translation>
    </message>
</context>
</TS>

==> novprog-3.1.1-1-src.tar.xz: novprog-3.1.1/translations/novprog_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Bar</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>מילה %Ln</numerusform>
            <numerusform>%Ln מילים</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחר שפת יישום:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>אנא אתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>NovelDialog</name>
    <message>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <source>Goals</source>
        <translation>יעדים</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date Range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Word Count</source>
        <translation>ספירת מילים</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>סך הכל:</translation>
    </message>
    <message>
        <source>Daily:</source>
        <translation>יומי:</translation>
    </message>
    <message>
        <source>Start On:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End On:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start At:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Novel</source>
        <translation>הוסף רומן</translation>
    </message>
    <message>
        <source>Edit Novel</source>
        <translation>ערוך רומן</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>מצטערים</translation>
    </message>
    <message>
        <source>A novel already exists with that name.</source>
        <translation>כבר קיים רומן עם שם זה.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Novel Progress</source>
        <translation>התקדמות רומן</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>סך הכל</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>יומי</translation>
    </message>
    <message>
        <source>Word count:</source>
        <translation>ספירת מילים:</translation>
    </message>
    <message>
        <source>&amp;Novel</source>
        <translation>&amp;רומן</translation>
    </message>
    <message>
        <source>&amp;New Novel</source>
        <translation>רומן &amp;חדש</translation>
    </message>
    <message>
        <source>&amp;Edit Novel</source>
        <translation>&amp;ערוך רומן</translation>
    </message>
    <message>
        <source>&amp;Delete Novel</source>
        <translation>&amp;מחק רומן</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;ערוך</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;מחק</translation>
    </message>
    <message>
        <source>Delete novel?</source>
        <translation>למחוק רומן?</translation>
    </message>
    <message>
        <source>Delete progress for the novel &apos;%1&apos;?</source>
        <translation>למחוק התקדמות עבור הרומן &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>This action cannot be undone.</source>
        <translation>פעולה זו היא בלתי הפיכה.</translation>
    </message>
</context>
</TS>
